.. SPDX-FileCopyrightText: Copyright © 2025 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _fairical.cli:

===================
 Command-line Apps
===================

The command-line apps provided implement :ref:`the workflow <fairical.datamodel>` in a
simplified manner (for full control, directly use the Python API).


.. click:: fairical.scripts.cli:cli
   :prog: fairical
   :nested: full


.. include:: links.rst
